@@ -5,11 +5,12 @@ from authlib.base_user import BaseUser
 
 
 def _obfuscate(email):
-    user, domain = email.rsplit("@", 1)
-    return "%s%s@***.%s" % (
-        user[:3],
-        "***" if len(user) > 3 else "",
-        domain.rsplit(".", 1)[-1],
+    user, _sep, domain = email.partition("@")
+    return (
+        "%s%s@***.%s"
+        % (user[:3], "***" if len(user) > 3 else "", domain.rsplit(".", 1)[-1],)
+        if domain
+        else "%s***" % (user[:3],)
     )
 
 
